@@ -5,7 +5,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.089_04';
+our $VERSION = '0.090_01';
 
 use Exporter qw{ import };
 
@@ -13,6 +13,8 @@ use Astro::Coord::ECI::TLE qw{ :constants };
 use Astro::Coord::ECI::Utils qw{ rad2deg };
 use Test::More 0.88;
 
+use constant CODE_REF	=> ref sub {};
+
 our @EXPORT_OK = qw{
     format_pass format_time
     magnitude
@@ -102,7 +104,7 @@ sub _format_optional {
     my ( $tplt, $hash, $key, $xfrm ) = @_;
     defined( my $val = $hash->{$key} )
 	or return '';
-    'CODE' eq ref $xfrm
+    CODE_REF eq ref $xfrm
 	and $val = $xfrm->( $val );
     return sprintf $tplt, $val;
 }
